# Table of Contents

- [fact-sheet-mapping-between-servicenow-and-sap-leanix](<./fact-sheet-mapping-between-servicenow-and-sap-leanix.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Fact Sheet Mapping Between ServiceNow and SAP LeanIX](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX.md>)
  - [Configuring a Fact Sheet Mapping](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Configuring-a-Fact-Sheet-Mapping.md>)
  - [Fact Sheet Mapping Parameters](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Fact-Sheet-Mapping-Parameters.md>)
  - [Configuring Field Mappings](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Configuring-Field-Mappings.md>)
  - [Field Mapping Parameters](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Field-Mapping-Parameters.md>)
  - [AI-Generated Field Mapping Suggestions](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/AI-Generated-Field-Mapping-Suggestions.md>)
  - [Mapping Type](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Mapping-Type.md>)
  - [Additional Configuration Details](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Additional-Configuration-Details.md>)
  - [Synchronization Filters](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Synchronization-Filters.md>)
  - [Filtering from SAP LeanIX to ServiceNow](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Filtering-from-SAP-LeanIX-to-ServiceNow.md>)
  - [Filtering from ServiceNow to SAP LeanIX](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Filtering-from-ServiceNow-to-SAP-LeanIX.md>)
  - [Graph Rule Constraints](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Graph-Rule-Constraints.md>)
  - [Mapping Multiple-Select Fields](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Mapping-Multiple-Select-Fields.md>)
  - [Mapping Lifecycle and Date Fields](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Mapping-Lifecycle-and-Date-Fields.md>)
  - [Mapping Multiple Fact Sheet Types to One ServiceNow Table](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Mapping-Multiple-Fact-Sheet-Types-to-One-ServiceNow-Table.md>)
  - [Was this page helpful?](<./Fact-Sheet-Mapping-Between-ServiceNow-and-SAP-LeanIX/Was-this-page-helpful.md>)
